@@ -8,6 +8,10 @@ use KiokuDB::Backend::Serialize::JSPON::Collapser;
 
 use namespace::clean -except => 'meta';
 
+with qw(
+    KiokuDB::Backend::TypeMap::Default::JSON
+);
+
 has expander => (
     isa => "KiokuDB::Backend::Serialize::JSPON::Expander",
     is  => "rw",
@@ -40,7 +44,7 @@ __END__
 
 =head1 NAME
 
-KiokuDB::Backend::Serialize::JSPON -
+KiokuDB::Backend::Serialize::JSPON - JSPON serialization helper
 
 =head1 SYNOPSIS
 
@@ -48,6 +52,9 @@ KiokuDB::Backend::Serialize::JSPON -
 
 =head1 DESCRIPTION
 
+This serialization role provides JSPON semantics for L<KiokuDB::Entry> and
+L<KiokuDB::Reference> objects.
+
 =cut
 
 
