@@ -3,8 +3,6 @@
 package KiokuDB::LiveObjects::TXNScope;
 use Moose;
 
-use Scalar::Util qw(weaken);
-
 use namespace::clean -except => 'meta';
 
 has entries => (
@@ -24,20 +22,14 @@ has parent => (
     is  => "ro",
 );
 
-sub push {
+sub update_entries {
     my ( $self, @entries ) = @_;
-
-    my $e = $self->entries;
-
-    foreach my $entry ( @entries ) {
-        push @$e, $entry;
-        weaken($e->[-1]);
-    }
+    push @{ $self->entries }, @entries;
 }
 
 sub rollback {
     my $self = shift;
-    $self->live_objects->rollback_entries(grep { defined } splice @{ $self->entries });
+    $self->live_objects->rollback_entries(splice @{ $self->entries });
 }
 
 sub DEMOLISH {
@@ -77,9 +69,6 @@ KiokuDB::LiveObjects::TXNScope - Transaction scope.
 This is an auxillary class used by transaction scoping to roll back entrries
 updated during a transaction when it is aborted.
 
-This is used internally in L<KiokuDB/txn_do> and should not need to be used
-directly.
-
 =head1 ATTRIBUTES
 
 =over 4
