@@ -5,7 +5,12 @@ use Moose;
 
 use namespace::clean -except => 'meta';
 
-has [qw(name age job binary)] => (
+has name => (
+    isa => "Str",
+    is  => "rw",
+);
+
+has job => (
     isa => "Str",
     is  => "rw",
 );
@@ -16,7 +21,19 @@ has so => (
     weak_ref => 1,
 );
 
-has [qw(parents kids friends)] => (
+has parents => (
+    isa => "ArrayRef[KiokuDB::Test::Person]",
+    is  => "rw",
+    default => sub { [] },
+);
+
+has kids => (
+    isa => "ArrayRef[KiokuDB::Test::Person]",
+    is  => "rw",
+    default => sub { [] },
+);
+
+has friends => (
     isa => "ArrayRef[KiokuDB::Test::Person]",
     is  => "rw",
     default => sub { [] },
